summaryrefslogtreecommitdiff
path: root/test/controls
diff options
context:
space:
mode:
Diffstat (limited to 'test/controls')
-rw-r--r--test/controls/control_range.cpp (renamed from test/controls/control_info.cpp)14
-rw-r--r--test/controls/meson.build2
2 files changed, 8 insertions, 8 deletions
diff --git a/test/controls/meson.build b/test/controls/meson.build
index f4fc7b94..9f0f005a 100644
--- a/test/controls/meson.build
+++ b/test/controls/meson.build
@@ -1,6 +1,6 @@
control_tests = [
- [ 'control_info', 'control_info.cpp' ],
[ 'control_list', 'control_list.cpp' ],
+ [ 'control_range', 'control_range.cpp' ],
[ 'control_value', 'control_value.cpp' ],
]
diff --git a/test/controls/control_info.cpp b/test/controls/control_range.cpp
index 9cf59185..06ec3506 100644
--- a/test/controls/control_info.cpp
+++ b/test/controls/control_range.cpp
@@ -2,7 +2,7 @@
/*
* Copyright (C) 2019, Google Inc.
*
- * control_info.cpp - ControlInfo tests
+ * control_range.cpp - ControlRange tests
*/
#include <iostream>
@@ -15,16 +15,16 @@
using namespace std;
using namespace libcamera;
-class ControlInfoTest : public Test
+class ControlRangeTest : public Test
{
protected:
int run()
{
/*
* Test information retrieval from a control with no minimum
* and maximum.
*/
- ControlInfo brightness;
+ ControlRange brightness;
if (brightness.min().get<int32_t>() != 0 ||
brightness.max().get<int32_t>() != 0) {
@@ -36,7 +36,7 @@ protected:
* Test information retrieval from a control with a minimum and
* a maximum value.
*/
- ControlInfo contrast(10, 200);
+ ControlRange contrast(10, 200);
if (contrast.min().get<int32_t>() != 10 ||
contrast.max().get<int32_t>() != 200) {
@@ -48,4 +48,4 @@ protected:
}
};
-TEST_REGISTER(ControlInfoTest)
+TEST_REGISTER(ControlRangeTest)
@@ -15,16 +15,16 @@
{
/*
- * Test information retrieval from a control with no minimum
- * and maximum.
+ * Test information retrieval from a range with no minimum and
+ * maximum.
*/